import 'package:flutter/material.dart';

// Класс приложения
void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      title: 'Flutter Demo',
      theme: ThemeData(
        // Настраиваем цветовую схему приложения
        colorScheme: ColorScheme.fromSeed(seedColor: Colors.indigoAccent),
        useMaterial3: true,
      ),
      home: const MyHomePage(title: 'Валова Анна Дмитриевна'),
    );
  }
}

// Класс домашней страницы
class MyHomePage extends StatefulWidget {
  const MyHomePage({super.key, required this.title});
  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  // Список слов и их переводов
  final List<Word> words = [
    Word(word: 'Hello', translation: 'Привет', image: 'https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcS69a8OWnRueQNykBpuyfbGxl3gt5ct46NOHg&s'),
    Word(word: 'Book', translation: 'Книга', image: 'https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcSfbH7Ckkbzrr3KZlb144GTaAmJnz87U9opGw&s'),
    Word(word: 'Cat', translation: 'Кот', image: 'https://upload.wikimedia.org/wikipedia/commons/0/0e/Felis_silvestris_silvestris.jpg'),
  ];

  int currentIndex = 0;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: Theme.of(context).colorScheme.inversePrimary,
        title: Text(widget.title),
      ),
      body: Center(
        child: SingleChildScrollView(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              for (var word in words)
                _Card(
                  word: word.word,
                  translation: word.translation,
                  image: word.image,
                ),
              // Кнопки "Знаю" и "Не знаю"
             /* Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  // Кнопка "Знаю"
                  ElevatedButton(
                    onPressed: () {
                      setState(() {
                        currentIndex++;
                        if (currentIndex >= words.length) {
                          currentIndex = 0;
                        }
                      });
                    },
                    child: const Text('Знаю'),
                  ),
                  const SizedBox(width: 20),
                  // Кнопка "Не знаю"
                  ElevatedButton(
                    onPressed: () {
                      // Переходим к предыдущей карточке
                      setState(() {
                        currentIndex--;
                        if (currentIndex < 0) {
                          currentIndex = words.length - 1;
                        }
                      });
                    },
                    child: const Text('Не знаю'),
                  ),
                ],
              ),*/
            ],
          ),
        ),
      ),
    );
  }
}

// Класс карточки
class _Card extends StatefulWidget {
  final String word;
  final String translation;
  final String image;

  const _Card({
    required this.word,
    required this.translation,
    required this.image,
  });

  @override
  State<_Card> createState() => _CardState();
}

class _CardState extends State<_Card> {
  bool isKnow = false;
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.all(20),
      margin: const EdgeInsets.all(10),
      decoration: BoxDecoration(
        color: Colors.black12,
        borderRadius: BorderRadius.circular(10),
      ),
        child: IntrinsicHeight(
          child: Column(
            children: [
              Image.network(widget.image, width: 300),
              Text(
                widget.word,
                style: Theme.of(context).textTheme.headlineLarge,
              ),
              // Перевод слова
              Text(
                widget.translation,
                style: Theme.of(context).textTheme.bodyMedium,
              ),
          Column(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Padding(
                    padding: const EdgeInsets.only(left: 8.0),
                    child: GestureDetector(
                      onTap: () {
                        setState(() {
                          isKnow = !isKnow;
                        });
                      },
                      child: AnimatedSwitcher(
                        duration: const Duration(milliseconds: 200),
                        child: isKnow
                            ? const Icon(
                                Icons.check_circle,
                                color: Colors.green,
                                key: ValueKey(0))
                            : const Icon(
                                Icons.check_circle_outline,
                                key: ValueKey(1)),
                      ),
                    ),
                  ),
                ],
              )
            ],
          ),
        ));
  }
}

// Класс для слов
class Word {
  final String word;
  final String translation;
  final String image;

  Word({required this.word, required this.translation, required this.image});
}